BrowserChannel adapter for the Jetty webserver, with async HTTP.
BrowserChannel adapter for the Jetty webserver, with async HTTP.
(run-jetty-async handler options)Serve the given handler according to the options. Options: :configurator - A function called with the Server instance. :port :host :join? - Block the caller: defaults to true. :response-timeout - Timeout after which the server will close the connection
Serve the given handler according to the options. Options: :configurator - A function called with the Server instance. :port :host :join? - Block the caller: defaults to true. :response-timeout - Timeout after which the server will close the connection
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |